@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 15.3 Debian package creator
-# Release 2019-03-18
+# DaVinci Resolve 16.0 Debian package creator
+# Release 2019-08-09
 # By Daniel Tufvesson
 #
 
@@ -57,8 +57,8 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=15.3
-DEB_STEPPING=2
+RESOLVE_VERSION=16.0
+DEB_STEPPING=1
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -100,17 +100,10 @@ create_directory ${DEB_DIR}
 create_directory ${RESOLVE_BASE_DIR}
 
 # Create directories
-create_directory ${RESOLVE_BASE_DIR}/configs
 create_directory ${RESOLVE_BASE_DIR}/easyDCP
-create_directory ${RESOLVE_BASE_DIR}/logs
 create_directory ${RESOLVE_BASE_DIR}/scripts
-create_directory ${RESOLVE_BASE_DIR}/.LUT
 create_directory ${RESOLVE_BASE_DIR}/.license
-create_directory ${RESOLVE_BASE_DIR}/.crashreport
-create_directory ${RESOLVE_BASE_DIR}/DolbyVision
-create_directory ${RESOLVE_BASE_DIR}/Fairlight
-create_directory ${RESOLVE_BASE_DIR}/Media
-create_directory ${RESOLVE_BASE_DIR}/"Resolve Disk Database"
+create_directory ${RESOLVE_BASE_DIR}/share
 
 # Copy objects
 copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
@@ -124,13 +117,15 @@ copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
+copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
 copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
 copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
 copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
-copy_object ${UNPACK_DIR}/share/default-config-linux.dat ${RESOLVE_BASE_DIR}/configs/config.dat-pkg-default
-copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/configs/log-conf.xml-pkg-default
-copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/DolbyVision/config.bin-pkg-default
+copy_object ${UNPACK_DIR}/share/default-config.dat ${RESOLVE_BASE_DIR}/share/
+copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/share/
+copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/share/
+copy_object ${UNPACK_DIR}/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/
 
 # Create udev rules
 create_directory ${DEB_DIR}/lib/udev/rules.d
@@ -145,6 +140,9 @@ EOF
 create_directory ${DEB_DIR}/usr/lib/
 extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
 
+# Create common data dir
+create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
+
 # Create desktop shortcut
 create_directory ${DEB_DIR}/usr/share/applications/
 cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
@@ -153,10 +151,11 @@ Version=1.0
 Encoding=UTF-8
 Exec=/opt/resolve/bin/resolve
 Icon=/opt/resolve/graphics/DV_Resolve.png
-MimeType=
 Name=${RESOLVE_NAME}
 Terminal=false
+MimeType=application/x-resolveproj;
 Type=Application
+StartupNotify=true
 Categories=AudioVideo
 EOF
 
@@ -172,21 +171,10 @@ Conflicts: ${DEB_CONFLICTS}
 EOF
 cat > ${DEB_DIR}/DEBIAN/postinst <<EOF
 #!/bin/sh
-test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pkg-default /opt/resolve/configs/config.dat
-test -e /opt/resolve/configs/log-conf.xml || cp /opt/resolve/configs/log-conf.xml-pkg-default /opt/resolve/configs/log-conf.xml
-test -e /opt/resolve/DolbyVision/config.bin || cp /opt/resolve/DolbyVision/config.bin-pkg-default /opt/resolve/DolbyVision/config.bin
-chmod -R a+rw /opt/resolve/configs
 chmod -R a+rw /opt/resolve/easyDCP
-chmod -R a+rw /opt/resolve/logs
-chmod -R a+rw /opt/resolve/Developer
-chmod -R a+rw /opt/resolve/DolbyVision
 chmod -R a+rw /opt/resolve/LUT
-chmod -R a+rw /opt/resolve/.LUT
 chmod -R a+rw /opt/resolve/.license
-chmod -R a+rw /opt/resolve/.crashreport
-chmod -R a+rw /opt/resolve/"Resolve Disk Database"
-chmod -R a+rw /opt/resolve/Fairlight
-chmod -R a+rw /opt/resolve/Media
+chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
 check_command fakeroot
